==> ansys_magnet_segmentation_toolkit-0.8.1-py3-none-any.whl: ansys/aedt/toolkits/magnet_segmentation/backend/api.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from ansys.aedt.toolkits.common.backend.api import AEDTCommon

from ansys.aedt.toolkits.magnet_segmentation.backend.models import properties
from ansys.aedt.toolkits.magnet_segmentation.backend.workflows.aedt import AEDTWorkflow


class ToolkitBackend(AEDTWorkflow, AEDTCommon):
    """Provides methods for controlling the toolkit workflow.

    This class provides methods for creating an AEDT session, connecting to an existing
    AEDT session, and automating the segmentation and skew of a 3D motor model.

    Examples
    --------
    >>> from ansys.aedt.toolkits.magnet_segmentation.backend.api import ToolkitBackend
    >>> toolkit = ToolkitBackend()
    >>> toolkit.launch_aedt()
    """

    def __init__(self):
        AEDTCommon.__init__(self, properties)
        super().__init__()

==> ansys_magnet_segmentation_toolkit-0.8.5-py3-none-any.whl: ansys/aedt/toolkits/magnet_segmentation/backend/api.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from pathlib import Path
import sys

# isort: off
sys.path.append(str(Path(__file__).parent))

# isort: on

from ansys.aedt.toolkits.magnet_segmentation.backend.workflows.aedt import AEDTWorkflow


class ToolkitBackend(AEDTWorkflow):
    """Provides methods for controlling the toolkit workflow.

    This class provides methods for creating an AEDT session, connecting to an existing
    AEDT session, and automating the segmentation and skew of a 3D motor model.

    Examples
    --------
    >>> from ansys.aedt.toolkits.magnet_segmentation.backend.api import ToolkitBackend
    >>> toolkit = ToolkitBackend()
    >>> toolkit.launch_aedt()
    """

    def __init__(self):
        AEDTWorkflow.__init__(self)
